@@ -1,6 +1,6 @@
 package Log::Any::Adapter::JSON;
 
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 use strict;
 use warnings;
@@ -63,10 +63,15 @@ sub _prepare_log_entry {
 
     confess 'Died: A log message is required' if ! $string;
 
-    my $meth = $self->{localtime} ? 'now' : 'now_utc';
+    my $method = $self->{localtime} ? 'now' : 'now_utc';
+
+    my $time  = Time::Moment->$method;
+    my $float = $time->strftime('%f');
+    $float ||= '.';
+    $float .= 0 while length $float < 7;
 
     my %log_entry = (
-        time     => Time::Moment->$meth->strftime('%FT%T%6f%Z'),
+        time     => join('', $time->strftime('%FT%T'), $float, $time->strftime('%Z')),
         level    => $level,
         category => $category,
     );
@@ -171,7 +176,7 @@ __END__
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =encoding utf8
 
